var definition = {
	"Agents": "This package contains classes which define the various types of actors which exist in the DDI-CDI Library, along with their supporting classes.",
	"Classes": "This package contains the definitions of the classes in the DDI-CDI Library, with all of their relationships and attributes. These are organized into topical/functional sub-packages to assist in their navigation and use.",
	"CollectionsPattern": "Template classes describing a group or collection of elements and their interrelationships. These classes support description of the way in which individual units of meaning, their representations, and other items of metadata can be assembled into groups with common characteristics and purpose.",
	"Components": "This package contains classes which define the roles played across the different data types by represented variables (pieces of information modeled according to that construct from the conceptual package). Each type of data is defined using a consistent approach, with a selection of the components a ...",
	"Conceptual": "This package contains the classes in the DDI-CDI Library which define foundational metadata constructs at the conceptual level. This includes not only the primary definitional class in the model - Concept - but also many of its significant applications: variables, units (of interest, not of measurem ...",
	"Context": "This package contains classes and their definitions taken from external standard models which are used to provide information about the alignment between them and the DDI-CDI model. These are in no sense the \"official\" definitions of these classes, but simply a way of providing a formal means of ind ...",
	"DCTerms": "This package contains classes taken from DCMI Metadata Terms (https://www.dublincore.org/specifications/dublin-core/dcmi-terms/#section-1) which are used in the DDI-CDI model. These classes represent the properties coming from both the elements and terms namespaces, represented as classes for inclus ...",
	"DDICDILibrary": "This package contains the classes, datatypes, and their definitions for all of the DDI-CDI model intended for direct use by implementers. It is organized into several sub-packages, as described below.",
	"DataDescription": "This package contains a number of sub-packages, looking at the variety of logical data types defined by DDI-CDI, their constituent components, and shared classes. These definitions cover both the structures of the different types of data, and also their specific instances (i.e., data sets) at a logi ...",
	"DataTypes": "This package contains the many different datatypes (e.g., logical value descriptions at a fine level of detail).",
	"DesignPatterns": "Packages that describe template classes and their relationships. These classes are not intended to be used directly, instead other classes \"realize\" them, duplicating all of their properties and associations. The patterns support consistency across the model.",
	"Dimensional": "This package contains the classes which are used to define multi-dimensional data structures (i.e., data cubes). It is important to note that the logical treatment of data as a multi-dimensional structure does not necessarily dictate a particular physical format for the data.",
	"Enumerations": "This package contains constructs for describing listed sets of values (enumerations).",
	"FormatDescription": "This package contains classes for tying the logical constructs in various data descriptions to physical formats.",
	"KeyValue": "This package contains classes which are used to define key-value data, as found in various types of no-SQL and \"big data\" systems and data warehouses.",
	"Long": "This package contains classes used to define data in which observations are arranged in a stream or flow, as from sensors or entry into administrative registers, and may be understood as events over time, even if irregular. Long structures may also be generated by procedures like the R melt() functi ...",
	"PROV": "This package contains classes which correspond directly to the constructs in the W3C PROV-O ontology (https://www.w3.org/TR/2013/REC-prov-o-20130430/)",
	"Process": "This package contains classes for describing the high-level processes and their substeps for linear (deterministic, imperative) and non-linear (non-deterministic, rule-based) processes.",
	"RDF": "Resource Description Framework (RDF) is a standard model for data interchange on the Web. See: https://www.w3.org/RDF/.",
	"Representations": "This package contains classes for describing the representation of values and meaning within data.",
	"SignificationPattern": "Template classes describing the symbolization of concepts or objects, and are related to the way in which meanings are represented in the model. This covers only the representation of individual units of meaning - the relationships between and among them are described in the Collections Pattern.",
	"StructuredDataTypes": "This package contains classes which describe logical values that have a complex (multi-part) structure.",
	"Wide": "This package contains classes for defining \"rectangular\" data files where each unit has a series of measurements recorded for it about a regular set of variables. (Although we often think of such data as existing in rows, logically it is independent of the specific formatting, and can be seen as a r ...",
	"XMLSchema": "XML Schema: Datatypes is part 2 of the specification of the XML Schema language. See: https://www.w3.org/TR/xmlschema-2/.",
	"XMLSchemaDataTypes": "This package contains the datatypes as defined in the W3C XML Schema specifications (https://www.w3.org/XML/Schema).",
	"Activity": "Something that occurs over a period of time and acts upon or with entities; it may include consuming, processing, transforming, modifying, relocating, using, or generating entities. (See the W3C PROV-O ontology, https://www.w3.org/TR/prov-dm/#term-Activity)",
	"Activity": "An activity is a task described at a conceptual level. It is not parameterized and as such is less reusable. For more logical/physical, fine-grained, reusable description there is a sub-type called step.",
	"Agent": "Something that bears some form of responsibility for an activity taking place, for the existence of an entity, or for another agent's activity. (See the W3C PROV-O ontology, https://www.w3.org/TR/prov-dm/#term-agent)",
	"Agent": "Actor that performs a role in relation to a process or product.",
	"AgentListing": "Listing of agents of any type who may be organized to describe relationships between agents.",
	"AgentPosition": "Assigns a sequence number to an agent in an agent listing.",
	"AgentRelationship": "Defines the relation of an agent within a structure.",
	"AgentStructure": "Defines the relationships between agents in a collection for a specified period and purpose.",
	"AllenIntervalAlgebra": "Control logic where the execution flow is determined by the satisfaction of temporal constraints specified with Allen's Interval Algebra over time intervals. Allen's interval algebra consists of thirteen temporal interval relations and the operations defined on them. Together these relations are dis ...",
	"AttributeComponent": "Role given to a represented variable in the context of a data structure to qualify observations or provide other types of supplementary information.",
	"AuthorizationSource": "Identifies the authorizing agency and allows for the full text of the authorization (law, regulation, or other form of authorization).",
	"Category": "Concept whose role is to define and measure a characteristic.",
	"CategoryPosition": "Assigns a sequence number to a category within a list.",
	"CategoryRelationStructure": "Description of the relationships between and among categories within a collection.",
	"CategoryRelationship": "Source-to-target relationship between categories in a structure.",
	"CategorySet": "Concept system where the underlying concepts are categories.",
	"CategoryStatistic": "Statistics related to a specific category of an instance variable within a data set.",
	"ClassificationFamily": "Collection of classification series related by being based on a common concept",
	"ClassificationIndex": "Ordered list of classification index entries.",
	"ClassificationIndexEntry": "Word or a short phrase corresponding to a classification item in a statistical classification, together with the code of the corresponding classification item.",
	"ClassificationIndexEntryPosition": "Member indicator for use with member type classification index entry.",
	"ClassificationItem": "A space for a category within a statistical classification.",
	"ClassificationItemPosition": "Provides a classification item with an index conveying the order of the classification item within a sequence, expressed as an integer, progressing upward from 0 or 1.",
	"ClassificationItemRelationship": "Source-target relationship between classification items in a classification item relation structure.",
	"ClassificationItemStructure": "Complex relation structure for use with statistical classification.",
	"ClassificationPosition": "The index of a classification within a classification family expressed as an integer, progressing upward from 0 or 1.",
	"ClassificationSeries": "Ensemble of one or more statistical classifications, based on the same concept, and related to each other as versions or updates.",
	"ClassificationSeriesStructure": "Structure for describing the complex relationships between statistical classifications in a classification series.",
	"Code": "The characters used as a symbol to designate a category within a codelist or classification. (Formally, a sign for which the signifier is non-linguistic alphanumeric string.)",
	"CodeList": "List of codes and associated categories.",
	"CodeListStructure": "Relation structure of codes within a codelist.",
	"CodePosition": "An index within an order intended for presentation (even though the content within levels of the hierarchy may be conceptually unordered). Expressed as an integer counting upward from 01 or 1.",
	"CodeRelationship": "Source target relationship between codes in a code relation structure.",
	"Collection": "Generic container that supports different types of groupings, from unordered sets to all sorts of hierarchies, nesting and ordered sets/bags.",
	"Comparison": "The minimal pattern for a comparison including a mapping between members.",
	"ComponentPosition": "Indexes the components in a data structure using integers with a position indicated by incrementing upward from 0 or 1.",
	"Concept": "Unit of thought differentiated by characteristics (from the Generic Statistical Information Model version 1.2: https://statswiki.unece.org/display/clickablegsim/Concept).",
	"ConceptMap": "Correspondence between concepts in a correspondence table.",
	"ConceptRelationship": "Relationship between a pair of concepts in a collection of concepts. Use controlled vocabulary provided in semantics to identify the type of relationship (relation, e.g. ParentChild, WholePart, etc.)",
	"ConceptStructure": "Relations of concepts within a collection.",
	"ConceptSystem": "Set of concepts structured by the relations among them [GSIM 1.1].",
	"ConceptSystemCorrespondence": "Relationship between 2 or more concept systems described through mapping similarity relationships between their member concepts.",
	"ConceptualDomain": "Set of concepts, where each concept is intended to be used as the meaning (signified) for a datum.",
	"ConceptualValue": "Concept (with a notion of equality defined) being observed, captured, or derived which is associated to a single data instance.",
	"ConceptualVariable": "A variable at the highest level of abstraction.",
	"ConditionalControlLogic": "A set of decision points which determine the flow between the steps used to perform an activity.",
	"ContextualComponent": "Encapsulates contextual information of the key-value datastore to provide a scope to the instance key. The instance key is unique within the scope.",
	"ControlLogic": "Control logic is a program in which the order of statements is explicit. Control logic is either deterministic (imperative) or non-deterministic (declarative). Deterministic control logic consists of control constructs. Declarative control logic is constraint- and/or rule-based. Control logic may co ...",
	"CorrespondenceTable": "Set of relationships between the members within or between statistical classifications.",
	"Curator": "Curator is a software agent that uses techniques such as natural language processing to map facts in the research data store to the condition part of a rule.",
	"DataPoint": "Container for an instance value.",
	"DataPointPosition": "Indexed location of the associated member within the associated list.",
	"DataPointRelationship": "Relations used by the data point relation structure of a logical record to describe specific source-target data points and their relationship.",
	"DataSet": "Organized collection of data based on keys.",
	"DataStore": "Collection of logical records.",
	"DataStructure": "Data organization based on reusable data structure components.",
	"DataStructureComponent": "Role given to a represented variable in the context of a data structure.",
	"Datum": "Correspondence of a data instance to the concept it represents.",
	"Descriptor": "Use of a code for variable identification in the context of a data structure and a variable descriptor component.",
	"DescriptorValueDomain": "Set of permissible values for a variable playing the role of a variable descriptor component.",
	"DescriptorVariable": "Variable that provides codes for variable identification in the context of a data structure. Variable playing the role of a variable descriptor component.",
	"DeterministicImperative": "Deterministic imperative is a subtype of control logic. Deterministic control logic consists of control constructs.",
	"DimensionComponent": "Role given to a represented variable in the context of a dimensional data structure to identify the universes associated with data points. The variable acts as a field in the compound identifier (the key structure) to disambiguate the cells in the multi-dimensional \"cube\".",
	"DimensionGroup": "Collection of dimensions that can be reused across multiple dimensional structures.",
	"DimensionalDataSet": "Organized collection of multidimensional data. It is structured by a dimensional data structure.",
	"DimensionalDataStructure": "Structure of a dimensional data set (organized collection of multidimensional data). It is described by dimension, measure and attribute components.",
	"DimensionalKey": "Collection of data instances that uniquely identify a collection of data points in a dimensional dataset.",
	"DimensionalKeyDefinition": "Collection of concepts that uniquely defines a collection of data points in a dimensional dataset.",
	"DimensionalKeyDefinitionMember": "Single concept that is part of a dimensional key definition.",
	"DimensionalKeyMember": "Single data instance that is part of a dimensional key.",
	"Entity": "A physical, digital, conceptual, or other kind of thing with some fixed aspects; entities may be real or imaginary. (See the W3C PROV-O ontology, https://www.w3.org/TR/prov-dm/#term-entity)",
	"EnumerationDomain": "A base class acting as an extension point to allow all codifications (codelist, statistical classification, etc.) to be understood as enumerated value domains.",
	"ForeignKey": "Role of a set of data structure components for content referencing purposes",
	"ForeignKeyComponent": "Role of a data structure component for content referencing purposes",
	"IdentifierComponent": "Role given to a represented variable in the context of a long or wide data structure to identify the units associated to data points, and in dimensional and key value data structures to provide identifying fields for the instance values.",
	"Individual": "A person. (See for example the W3C Friend of a Friend Ontology - http://xmlns.com/foaf/spec/#term_Person).",
	"IndividualMember": "Distinct element that is not itself a collection (atomic).",
	"InformationFlowDefinition": "The relationships between parameters across steps is described by the information flow definition. Each relationship creates a pathway for an information object to follow.",
	"InstanceKey": "Single-valued key representation produced from the merge of the representations of all key members and a descriptor.",
	"InstanceValue": "Single data instance corresponding to a concept (with a notion of equality defined) being observed, captured, or derived.",
	"InstanceVariable": "Use of a represented variable within a data set.",
	"InstanceVariableMap": "Key value relationship for two or more logical records where the key is one or more equivalent instance variables and the value is a defined relationship or a relationship to a set value.",
	"Key": "Collection of data instances that uniquely identify a collection of data points in a dataset.",
	"KeyDefinition": "Collection of concepts that uniquely defines a collection of data points in a dataset.",
	"KeyDefinitionMember": "Single concept that is part of the structure of a key definition.",
	"KeyMember": "Single data instance that is part of a key.",
	"KeyValueDataStore": "Organized collection of key-value data. It is structured by a key value structure.",
	"KeyValueStructure": "Structure of a key-value datastore (organized collection of key-value data). It is described by identifier, contextual, synthetic id, dimension, variable descriptor and variable value components.",
	"Level": "Set of all classification items the same number of relationships from the root (or top) classification item.",
	"LevelStructure": "Nesting structure of a hierarchical collection.",
	"List": "Simple ordered Collection defined as a list of Members where the location of each Member in the list is given by the associated Position class.",
	"LogicalRecord": "Collection of instance variables.",
	"LogicalRecordPosition": "Assigns a position of the logical record within the data store.",
	"LogicalRecordRelationStructure": "Structuring of relationships between logical records in a data store.",
	"LogicalRecordRelationship": "Relationships between logical records.",
	"LongDataSet": "Organized collection of long data. It is structured by a long data structure.",
	"LongDataStructure": "Structure of a long dataset (organized collection of long data). It is described by identifier, measure, attribute, variable descriptor and variable value components.",
	"LongKey": "Collection of data instances that uniquely identify a collection of data points in a long dataset.",
	"LongMainKeyMember": "Single data instance that is part of a long key.",
	"Machine": "Mechanism or computer program used to perform an act.",
	"MainKeyMember": "Identifies the unit of interest, either a statistical unit or a population, via identifier or dimension components, respectively, plus an optional contextual component. If neither identifier nor dimension components are present, then a synthetic id component is used.",
	"Map": "Provides a basic pattern for a comparison map which identifies source and target members and details about their match. Source and target were retained as in describing differences and commonalities the direction of the comparison may be important.",
	"MeasureComponent": "Role given to a represented variable in the context of a data structure to hold the observed/derived values.",
	"Member": "Element in a collection that can be either atomic (individual member) or composite (collection).",
	"MemberRelationship": "Relationship between members in a collection with directionality given by source and target.",
	"NonDeterministicDeclarative": "Non-deterministic control logic is a subtype of control logic. Non-deterministic (or declarative) control logic is constraint- and/or rule-based.",
	"Notation": "Representation of a category in the context of a code or a classification item, as opposed of the corresponding instance value which would appear when used in a dataset.",
	"Organization": "Collection of people organized within a framework of authority that can perform an act or be associated with another agent.",
	"Parameter": "An input or output to control logic and the step/sub-step it invokes. Parameters may take the form of any information object, including data sets and structured metadata as well as configuration information for the step/sub-step.",
	"PhysicalDataSet": "Information needed for understanding the physical structure of data coming from a file or other source.",
	"PhysicalDataSetStructure": "Ordering for physical record segments, which map to a logical record.",
	"PhysicalLayoutRelationStructure": "Realization of relation structure that is used to describe the sequence of value mappings in a physical layout.",
	"PhysicalRecordSegment": "Description of each physical storage segment required to completely cover a physical record representing the logical record.",
	"PhysicalRecordSegmentPosition": "Assigns a position of the physical record segment within the whole physical record. For example in what order does this 80 character segment fall within an 800 character record.",
	"PhysicalRecordSegmentRelationship": "Structured relationship between physical record segments.",
	"PhysicalRecordSegmentStructure": "Means for describing the complex relational structure of data points in a physical record representing the logical record.",
	"PhysicalSegmentLayout": "Used as an extension point in the description of the different layout styles of data structure descriptions.",
	"PhysicalSegmentLocation": "Location of a data point in a physical segment.",
	"Population": "Universe with time and geography specified.",
	"Position": "Position of the associated member within the associated List.",
	"PrimaryKey": "Role of a set of data structure components for content linkage purposes",
	"PrimaryKeyComponent": "Role of a data structure component for content identification purposes",
	"ProcessingAgent": "A processing agent orchestrates the production of information objects in a production environment. There are processing agents which perform data capture, data editing/processing, and data analysis (etc.), each in the appropriate production environments. The processing agent performs an activity bas ...",
	"ProductionEnvironment": "Production environments consume and produce information objects by way of processing pipelines orchestrated by the processing agent.",
	"QualifiedMeasure": "A measure having a specific production method.",
	"RecordRelation": "Relationships among record types within and between logical records.",
	"ReferenceValue": "Recorded value in a variable value component. Value referenced by a descriptor.",
	"ReferenceValueDomain": "Set of permissible values for a variable playing the role of a variable value component.",
	"ReferenceVariable": "Variable that records values of multiple variables in the context of a data structure. Variable playing the role of a variable value component.",
	"RepresentedVariable": "Conceptual variable with a substantive value domain specified.",
	"RevisableDatum": "A datum that can be qualified by a revision.",
	"Revision": "Algorithm applied to produce a revised datum.",
	"Rule": "A rule has a condition part and an action part. A rule takes the form of: If [Condition<U+007D> Then [Action]. A rule belongs to a rule set which is a component of rule based scheduling performed by the processing agent",
	"RuleBasedScheduling": "Rule based scheduling performs a fact check on rules from the rule set, testing their condition part against the facts in the research data store. Fact checking may be assisted by a curator who can semantically compare the condition part of each candidate rule with the facts. The fact checker return ...",
	"RuleSet": "A rule set is a collection of rules. A rule set is a component of rule based scheduling.",
	"ScopedMeasure": "A qualified measure whose domain is a universe as an aggregate, i.e. a measure with a specific production method applied to a specific cell in a cube.",
	"SegmentByText": "Location of a segment of text through character or line counts.",
	"SentinelConceptualDomain": "Conceptual domain of sentinel concepts.",
	"SentinelValueDomain": "Value domain for a sentinel conceptual domain.",
	"Sequence": "A sequence controls the order of activities or steps by defining a simple sequence.",
	"SequencePosition": "Assigns a sequence number to an activity within a sequence.",
	"Service": "Service is a type of processing agent. Services are atomic. They execute acts which have input and output parameters.",
	"Sign": "Something that suggests the presence or existence of a fact, condition, or quality.",
	"Signified": "Concept or object denoted by the signifier associated to a sign.",
	"Signifier": "Concept whose extension includes perceivable objects.",
	"StatisticalClassification": "Set of categories represented by classification items where the subset of immediate children categories for any given parent category are mutually exclusive and jointly exhaustive with respect to that parent.",
	"StatisticalClassificationRelationship": "Specifies the statistical classifications for the source and target of a complex relationship and defines the relationship.",
	"Step": "Step is a reusable, parameterized activity associated to information flows. One or more steps perform an sctivity.",
	"Structure": "Organized set of relationships between members in a collection. These relationships can be characterized mathematically in terms of reflexivity, symmetry and transitivity, or informally in terms of the collection's topology, e.g. network, tree, etc. In both cases it can also be defined either on all ...",
	"SubstantiveConceptualDomain": "Conceptual domain of substantive concepts.",
	"SubstantiveValueDomain": "Value domain for a substantive conceptual domain. Typically a description and/or enumeration of allowed values of interest.",
	"SyntheticIdComponent": "Persistent and unique identifier (PIDs) to provide standarized, long-lasting identification.",
	"TemporalConstraints": "Temporal constraints provide a mechanism for expressing concurrency control and synchronization",
	"TemporalControlConstruct": "Declarative control flow operator where the continuation of the execution flow depends on the finalization of one or more preceding activities/steps. - XORJoin: Given three activities A, B and C, if XORJoin(A, B) -> C, then C is executed after either A or B finishes executing. XORJoin is sometimes r ...",
	"Unit": "Individual object of interest for some statistical activity, such as data collection.",
	"UnitSegmentLayout": "Description of unit-record (\"wide\") data sets, where each row in the data set provides the same group of values for variables all relating to a single unit.",
	"UnitType": "Unit type is a type or class of objects of interest (units).",
	"Universe": "Specialized unit type, with the specialization based upon characteristics other than time and geography.",
	"ValueAndConceptDescription": "Formal description of a set of values.",
	"ValueDomain": "Set of permissible values for a variable (adapted from ISO/IEC 11179).",
	"ValueMapping": "Physical characteristics for the value of an instance variable stored in a data point as part of a physical segment layout.",
	"ValueMappingPosition": "Denotes the position of a value mapping in a sequence.",
	"ValueMappingRelationship": "Relationships among data points in a physical layout.",
	"VariableCollection": "Group of any type of variable within the variable cascade (conceptual, represented, instance).",
	"VariableDescriptorComponent": "Role given to a represented variable in the context of a data structure to provide codes for variable identification.",
	"VariablePosition": "Assigns a sequence number to a variable within a list.",
	"VariableRelationship": "Relationship between any variables in the variable cascade (conceptual, represented, instance), based on an ordered relation.",
	"VariableStructure": "Relation structure for use with any set of variables in the variable cascade (conceptual, represented, instance).",
	"VariableValueComponent": "Role given to a represented variable in the context of a data structure to record values of multiple variables.",
	"WideDataSet": "Organized collection of wide data. It is structured by a wide data structure.",
	"WideDataStructure": "Structure of a wide dataset (organized collection of wide data). It is described by identifier, measure and attribute components.",
	"WideKey": "Collection of data instances that uniquely identify a collection of data points in a wide dataset.",
	"WideKeyMember": "Single data instance that is part of a wide key.",
	"AccessInformation": "A set of information important for understanding access conditions.",
	"AccessLocation": "A set of access information for a machine including URI, mime type, and physical location.",
	"Address": "Location address identifying each part of the address as separate elements, identifying the type of address, the level of privacy associated with the release of the address, and a flag to identify the preferred address for contact.",
	"AgentInRole": "A reference to an agent (organization, individual, or machine) including a role for that agent in the context of this specific reference.",
	"BibliographicName": "Personal names should be listed surname or family name first, followed by forename or given name. When in doubt, give the name as it appears, and do not invert. In the case of organizations where there is clearly a hierarchy present, list the parts of the hierarchy from largest to smallest, separate ...",
	"CatalogDetails": "A set of information useful for attribution, data discovery, and access.",
	"CategoryRelationCode": "Indicates the type of relationship, nominal, ordinal, interval, ratio, or continuous. Use where appropriate for the representation type.",
	"CombinedDate": "Provides the structure of a single Date expressed in an ISO date structure along with equivalent expression in any number of non-ISO formats. While it supports the use of the ISO time interval structure this should only be used when the exact date is unclear (i.e. occurring at some point in time bet ...",
	"Command": "Provides the following information on the command: The content of the command and the programming language used.",
	"CommandCode": "Contains information on the command used for processing data. Contains a description of the command which should clarify for the user the purpose and process of the command, an in-line provision of the command itself, and a reference to an external version of the command such as a coding script.",
	"CommandFile": "Identifies and provides a link to an external copy of the command, for example, a SAS Command Code script. Designates the programming language of the command file, a description of the location of the file , and a URN or URL for the command file.",
	"ComparisonOperator": "Defines the relationship between values in key/value pair.",
	"ComputationBaseList": "Defines the cases included in determining the statistic.",
	"ContactInformation": "Contact information for the individual or organization including location specification, address, web site, phone numbers, and other means of communication access. Address, location, telephone, and other means of communication can be repeated to express multiple means of a single type or change over ...",
	"ControlConstruct": "Type of control construct used by the conditional control logic related to an activity.",
	"ControlledVocabularyEntry": "Allows for unstructured content which may be an entry from an externally maintained controlled vocabulary.If the content is from a controlled vocabulary provide the code value of the entry, as well as a reference to the controlled vocabulary from which the value is taken. Provide as many of the iden ...",
	"CorrespondenceDefinition": "Describes the commonalities and differences between two members using a textual description of both commonalities and differences plus an optional coding of the type of commonality.",
	"DateRange": "Expresses a date/time range using a start date and end date (both with the structure of Date and supporting the use of ISO and non-ISO date structures). Use in all locations where a range of dates is required, i.e. validFor, embargoPeriod, collectionPeriod, etc.",
	"ElectronicMessageSystem": "Any non-email means of relaying a message electronically. This would include text messaging, Skype, Twitter, ICQ, or other emerging means of electronic message conveyance.",
	"Email": "An e-mail address which conforms to the internet format (RFC 822) including its type and time period for which it is valid.",
	"EmbargoInformation": "Specific information about any relevant embargo.",
	"FundingInformation": "Information regarding the source of funds used to develop or support the resource being described.",
	"GeoRole": "Geography-specific role given to a represented variable in the context of a data structure. The specific characterization of the role (e.g. reference, coordinates, etc.) may be given by a controlled vocabulary.",
	"Identifier": "Identifier for objects requiring short- or long-lasting referencing and management.",
	"IndividualName": "The name of an individual broken out into its component parts of prefix, first/given name, middle name, last/family/surname, and suffix. The preferred compilation of the name parts may also be provided. The legal or formal name of the individual should have the isFormal attribute set to true. The pr ...",
	"InternationalIdentifier": "An identifier whose scope of uniqueness is broader than the local archive. Common forms of an international identifier are ISBN, ISSN, DOI or similar designator. Provides both the value of the identifier and the agency who manages it.",
	"InternationalRegistrationDataIdentifier": "Persistent, globally unique object identifier aligned with ISO/IEC 11179-6:2015, Information technology - Metadata registries (MDR) - Part 6: Registration, Annex A, Identifiers based on ISO/IEC 6523, http://standards.iso.org/ittf/PubliclyAvailableStandards/c060342_ISO_IEC_11179-6_2015.zip. The uniqu ...",
	"InternationalString": "Packaging structure for multilingual versions of the same string content, represented by a set of LanguageString. Only one LanguageString per language/scope type is allowed. Where an element of this type (InternationalString) is repeatable, the expectation is that each repetition contains a differen ...",
	"LabelForDisplay": "A structured display label. Label provides display content of a fully human readable display for the identification of the object.",
	"LanguageString": "A data type which describes a string specific to a language/scope combination. It contains the following attributes: language to designate the language, isTranslated with a default value of false to designate if an object is a translation of another language, isTranslatable with a default value of t ...",
	"LicenseInformation": "Information about any relevant license.",
	"MatchingCriterion": "Supports mapping comparative relationships by type of match. Not used for causative, sequential, temporal or special relations.",
	"MemberRelationshipScope": "A vocabulary for the specification of how much of a collection is referenced. All, some or none of the collection may be indicated.",
	"ModelIdentification": "Attributes for the model identification with constant values.",
	"NonDdiIdentifier": "A unique set of attributes, not conforming to the DDI identifier structure nor structured as a URI, used to identify some entity.",
	"NonIsoDate": "Used to preserve an historical date, formatted in a non-ISO fashion.",
	"ObjectAttributeSelector": "A resource which describes a specific attribute of an object. It is defined in the style of selectors of the Web Annotation Vocabulary, see https://www.w3.org/TR/annotation-vocab/. The selector can be nested dependent on the structure of the referenced object.",
	"ObjectName": "A standard means of expressing a name for a class object. A linguistic signifier. Human understandable name (word, phrase, or mnemonic) that reflects the ISO/IEC 11179-5 naming principles.",
	"OrganizationName": "Names by which the organization is known. Use the attribute isFormal with a value of True to designate the legal or formal name of the organization. Names may be typed with typeOfOrganizationName to indicate their appropriate usage.",
	"PairedControlledVocabularyEntry": "A tightly bound pair of items from an external controlled vocabulary. The extent property describes the extent to which the parent term applies for the specific case.",
	"PointFormat": "Provides an enumerated list of valid point format types for capturing a coordinate point.",
	"PrivateImage": "References an image using the standard Image description. In addition to the standard attributes provides an effective date (period) and a privacy ranking.",
	"ProvenanceInformation": "Basic information about the provenance of the object. Includes a simple description, but not detailed modeling of a process.",
	"RationaleDefinition": "Textual description of the rationale/purpose for the version change and a coded value to provide an internal processing flag within and organization or system.",
	"Reference": "Provides a way of pointing to resources outside of the information described in the set of DDI-CDI metadata.",
	"SchedulingStrategy": "Enumeration that consists of forward chaining and backward chaining. Rule based scheduling is guided by its scheduling strategy.",
	"Selector": "A resource which describes the segment of interest in a representation of a resource. This class is not used directly, only its subclasses. It is defined accordingly the related selector of the Web Annotation Vocabulary, see https://www.w3.org/TR/annotation-vocab/#selector.",
	"SexSpecification": "Sex specification is limited to the purpose of determining the proper pronoun to use in addressing the individual. This may be based on conventional usage or personal preference.",
	"SpatialCoordinate": "Lists the value and format type for the coordinate value. Note that this is a single value (X coordinate or Y coordinate) rather than a coordinate pair.",
	"SpatialPoint": "A geographic point consisting of an X and Y coordinate. Each coordinate value is expressed separately providing its value and format.",
	"SpecializationRole": "Specific roles played by represented variables in terms of time, geography, and other concepts which are important for the harmonization and integration of data.",
	"Statistic": "The value of the statistic expressed as a decimal, float and/or double. Indicates whether it is weighted value and the computation base.",
	"StructureExtent": "Type of relation in terms of totality with respect to an associated collection. The totality type is given by the controlled vocabulary <U+007B>total, partial<U+007D>.",
	"StructureSpecification": "The mathematical properties of the structure.",
	"TableDirectionValues": "Indicates whether the tables in the group should be displayed with the first column on the right, on the left, or based on the first character in the table that has a specific direction.",
	"Telephone": "Details of a telephone number including the number, type of telephone number, a privacy setting and an indication of whether this is the preferred contact number.",
	"TemporalOperator": "Set of control flow operators where the continuation of the execution flow depends on the finalization of one or more preceding activities.",
	"TemporalRelation": "Set of thirteen Allen's interval relations defined as Contains, Finishes, Meets, Overlaps, Precedes, Starts (and their converses), plus Equals. These are jointly exhaustive and pairwise disjoint binary relations representing temporal relationships between pairs of time intervals.",
	"TextDirectionValues": "Indicates whether the text within cells should be displayed as left-to-right text (ltr), as right-to-left text (rtl), according to the content of the cell (auto) or in the direction inherited from the table direction annotation of the table.",
	"TextPositionSelector": "Describes a range of text by recording the start and end positions of the selection in the object. Position 0 would be immediately before the first character, position 1 would be immediately before the second character, and so on. It is defined accordingly the related selector of the Web Annotation ...",
	"TimeRole": "Time-specific role given to a represented variable in the context of a data structure. The specific characterization of the role (e.g. event, valid, transaction, reference, etc.) may be given by a controlled vocabulary.",
	"TrimValues": "Specifies which spaces to remove from a data value (start, end, both, neither).",
	"TypedString": "TypedString combines a type with content defined as a simple string. May be used wherever a simple string needs to support a type definition to clarify its content.",
	"WebLink": "A web site (normally a URL) with information on type of site, privacy flag, and effective dates.",
	"WhiteSpaceRule": "WhiteSpace constrains the value space of types derived from string.",
	"XsdAnyUri": "Primitive data type \"anyURI\" of the XML Schema data types. Definition from XML Schema Part 2: Datatypes Second Edition: \"anyURI\" represents a Uniform Resource Identifier Reference (URI). An \"anyURI\" value can be absolute or relative, and may have an optional fragment identifier (i.e., it may be a UR ...",
	"XsdDate": "Primitive data type \"date\" of the XML Schema data types. Definition from XML Schema Part 2: Datatypes Second Edition: \"The value space of date consists of top-open intervals of exactly one day in length on the timelines of dateTime, beginning on the beginning moment of each day (in each timezone), i ...",
	"XsdLanguage": "Derived data type \"language\" of the XML Schema data types. Definition from XML Schema Part 2: Datatypes Second Edition: \"language\" represents natural language identifiers as defined by by [RFC 3066]. The value space of \"language\" is the set of all strings that are valid language identifiers as defin ...",
	"abstract": "A summary of the resource. (See DCMI Metadata Terms - https://www.dublincore.org/specifications/dublin-core/dcmi-terms/#http://purl.org/dc/terms/abstract.)",
	"accessRights": "Information about who access the resource or an indication of its security status. Access Rights may include information regarding access or restrictions based on privacy, security, or other policies. (See DCMI Metadata Terms - https://www.dublincore.org/specifications/dublin-core/dcmi-terms/#http:/ ...",
	"alternative": "An alternative name for the resource. The distinction between titles and alternative titles is application-specific. (See DCMI Metadata Terms - https://www.dublincore.org/specifications/dublin-core/dcmi-terms/#http://purl.org/dc/terms/alternative.)",
	"anyURI": "Definition from XML Schema Part 2: Datatypes Second Edition: \"anyURI\" represents a Uniform Resource Identifier Reference (URI). An \"anyURI\" value can be absolute or relative, and may have an optional fragment identifier (i.e., it may be a URI Reference). This type should be used to specify the inten ...",
	"contributor": "An entity responsible for making contributions to the resource. The guidelines for using names of persons or organizations as creators also apply to contributors. Typically, the name of a Contributor should be used to indicate the entity. (See DCMI Metadata Terms - https://www.dublincore.org/specifi ...",
	"creator": "An entity responsible for making the resource. Recommended practice is to identify the creator with a URI. If this is not possible or feasible, a literal value that identifies the creator may be provided. (See DCMI Metadata Terms - https://www.dublincore.org/specifications/dublin-core/dcmi-terms/#ht ...",
	"date": "A point or period of time associated with an event in the lifecycle of the resource. Date may be used to express temporal information at any level of granularity. Recommended practice is to express the date, date/time, or period of time according to ISO 8601-1 [ISO 8601-1] or a published profile of ...",
	"date": "Definition from XML Schema Part 2: Datatypes Second Edition: \"The value space of date consists of top-open intervals of exactly one day in length on the timelines of dateTime, beginning on the beginning moment of each day (in each timezone), i.e. '00:00:00', up to but not including '24:00:00' (which ...",
	"format": "The file format, physical medium, or dimensions of the resource. Recommended practice is to use a controlled vocabulary where available. For example, for file formats one could use the list of Internet Media Types [MIME].",
	"identifier": "An unambiguous reference to the resource within a given context. Recommended practice is to identify the resource by means of a string conforming to an identification system.",
	"langString": "The datatype of language-tagged string values. Defined according to the data type langString in RDF, see https://www.w3.org/TR/rdf-schema/#ch_langstring and https://www.w3.org/1999/02/22-rdf-syntax-ns#langString.",
	"language": "A language of the resource. Recommended practice is to use either a non-literal value representing a language from a controlled vocabulary such as ISO 639-2 or ISO 639-3, or a literal value consisting of an IETF Best Current Practice 47 [IETF-BCP47] language tag. (See DCMI Metadata Terms - https://w ...",
	"language": "Definition from XML Schema Part 2: Datatypes Second Edition: \"language\" represents natural language identifiers as defined by by [RFC 3066]. The value space of \"language\" is the set of all strings that are valid language identifiers as defined [RFC 3066] . The lexical space of language is the set of ...",
	"provenance": "A statement of any changes in ownership and custody of the resource since its creation that are significant for its authenticity, integrity, and interpretation. The statement may include a description of any changes successive custodians made to the resource. (See DCMI Metadata Terms - https://www.d ...",
	"publisher": "An entity responsible for making the resource available. (See DCMI Metadata Terms - https://www.dublincore.org/specifications/dublin-core/dcmi-terms/#http://purl.org/dc/terms/publisher.)",
	"relation": "A related resource. Recommended practice is to identify the related resource by means of a URI. If this is not possible or feasible, a string conforming to a formal identification system may be provided. (See DCMI Metadata Terms - https://www.dublincore.org/specifications/dublin-core/dcmi-terms/#htt ...",
	"source": "A related resource from which the described resource is derived. This property is intended to be used with non-literal values. The described resource may be derived from the related resource in whole or in part. Best practice is to identify the related resource by means of a URI or a string conformi ...",
	"title": "A name given to the resource. (See DCMI Metadata Terms - https://www.dublincore.org/specifications/dublin-core/dcmi-terms/#http://purl.org/dc/terms/title.)",
	"type": "The nature or genre of the resource. Recommended practice is to use a controlled vocabulary such as the DCMI Type Vocabulary [DCMI-TYPE]. To describe the file format, physical medium, or dimensions of the resource, use the property Format. (See DCMI Metadata Terms - https://www.dublincore.org/specif ...",
}
